Module guild

Module guild 

Guild-related data models for the QQ Guild Bot API.

This module contains guild types for the QQ Bot Open API.

Structs

Guild
Represents a guild (server) in the QQ Guild system.
GuildMembersPager
Pager for guild member list requests.
GuildPager
Pager for current-user guild list requests.
GuildRole
Represents a role in a guild.
GuildRoleMembers
Response returned by the guild role members endpoint.
GuildRoleMembersPager
Pager for guild role member list requests.
GuildRoles
Guild roles response wrapper.
Member
Represents a member of a guild.
MemberAddRoleBody
Body used when adding or deleting a member role.
MemberDeleteOptions
Additional options for deleting a guild member.
UpdateGuildMute
Body for guild mute endpoints.
UpdateGuildMuteResponse
Response for batch guild mute.
UpdateResult
Result returned from role create/update APIs.
UpdateRole
Role update body.
UpdateRoleFilter
Filter identifying which role fields are being updated.
UpdateRoleInfo
Role update info body.

Constants

DEFAULT_ROLE_COLOR
Default role color used when creating or updating roles.

Functions

normalize_delete_history_msg_days
Normalizes history deletion days to the official supported values.