Data models for the BotRS library.
This module contains all the data structures used for interacting with the QQ Guild Bot API, including messages, guilds, users, channels, and other entities.
Re-exports
pub use guild::Guild;pub use guild::Member;pub use guild::Role;pub use announce::*;pub use api::*;pub use channel::*;pub use emoji::*;pub use gateway::*;pub use message::*;pub use message_setting::*;pub use permission::*;pub use robot::*;pub use schedule::*;pub use user::*;pub use webhook::*;
Modules
- announce
- Announcement-related data structures for the QQ Guild Bot API.
- api
- API response models for the QQ Guild Bot API.
- channel
- Channel-related data models for the QQ Guild Bot API.
- emoji
- Emoji-related data structures for the QQ Guild Bot API.
- gateway
- Gateway event models for the QQ Guild Bot API.
- guild
- Guild-related data models for the QQ Guild Bot API.
- message
- Message-related data models for the QQ Guild Bot API.
- message_
setting - Message setting data models for the QQ Guild Bot API.
- permission
- Permission-related data structures for the QQ Guild Bot API.
- robot
- Robot (bot) related data models for the QQ Guild Bot API.
- schedule
- Schedule-related data structures for the QQ Guild Bot API.
- user
- User-related data models for the QQ Guild Bot API.
- webhook
- HTTP webhook session models.
Structs
Enums
- Message
Type - Represents the type of a message.
Traits
- HasId
- Common trait for objects that have a snowflake ID.
- HasName
- Common trait for objects that have a name.
- Pager
- Pager trait.